unit Sys;

{$H+}

interface

uses Windows;

type
{ System Locale information record }
  TSysLocale = packed record
    DefaultLCID: LCID;
    PriLangID: LANGID;
    SubLangID: LANGID;
    FarEast: Boolean;
    MiddleEast: Boolean;
  end;

var
  ThousandSeparator: Char;
  DecimalSeparator: Char;
  SysLocale: TSysLocale;
  LeadBytes: set of Char = [];

{ Initialization file support }

function GetLocaleChar(Locale,LocaleType: Integer; Default: Char): Char;
procedure GetFormatSettings;

implementation

{ Initialization file support }

function GetLocaleChar(Locale, LocaleType: Integer; Default: Char): Char;
var Buffer: array[0..1] of Char;
begin
  if GetLocaleInfo(Locale,LocaleType,Buffer,2)>0 then Result:=Buffer[0] else Result:=Default;
end;

procedure InitSysLocale;
var DefaultLCID: LCID;
    DefaultLangID: LANGID;
    AnsiCPInfo: TCPInfo;
    I: Integer;
    J: Byte;
begin
  { Set default to English (US). }
  SysLocale.DefaultLCID:=$0409;
  SysLocale.PriLangID:=LANG_ENGLISH;
  SysLocale.SubLangID:=SUBLANG_ENGLISH_US;
  DefaultLCID:=GetThreadLocale;
  if DefaultLCID<>0 then SysLocale.DefaultLCID:=DefaultLCID;
  DefaultLangID:=Word(DefaultLCID);
  if DefaultLangID<>0 then
  begin
    SysLocale.PriLangID:=DefaultLangID and $3ff;
    SysLocale.SubLangID:=DefaultLangID shr 10;
  end;
  SysLocale.MiddleEast:=GetSystemMetrics(SM_MIDEASTENABLED)<>0;
  SysLocale.FarEast:=GetSystemMetrics(SM_DBCSENABLED)<>0;
  if not SysLocale.FarEast then Exit;
  GetCPInfo(CP_ACP,AnsiCPInfo);
  with AnsiCPInfo do
  begin
    I:=0;
    while (I<MAX_LEADBYTES) and ((LeadByte[I] or LeadByte[I+1])<>0) do
    begin
      for J:=LeadByte[I] to LeadByte[I+1] do Include(LeadBytes,Char(J));
      Inc(I,2);
    end;
  end;
end;

procedure GetFormatSettings;
var DefaultLCID: LCID;
begin
  InitSysLocale;
  DefaultLCID:=GetThreadLocale;
  ThousandSeparator:=GetLocaleChar(DefaultLCID,LOCALE_STHOUSAND,',');
  DecimalSeparator:=GetLocaleChar(DefaultLCID,LOCALE_SDECIMAL,'.');
end;

end.

